@@ -436,6 +436,11 @@ static char sccsid[] = "@(#)syslogd.c	5.27 (Berkeley) 10/10/88";
  *	Removed unixm/unix domain sockets and switch to Datagram Unix
  *	Sockets.  This should remove one possibility to play DoS with
  *	syslogd.  Thanks to Olaf Kirch <okir@caldera.de> for the patch.
+ *
+ * Sun Mar 11 20:23:44 CET 2001: Martin Schulze <joey@infodrom.ffis.de>
+ *	Don't return a closed fd if `-a' is called with a wrong path.
+ *	Thanks to Bill Nottingham <notting@redhat.com> for providing
+ *	a patch.
  */
 
 
@@ -870,7 +875,7 @@ int main(argc, argv)
 			StripDomains = crunch_list(optarg);
 			break;
 		case 'v':
-			printf("syslogd %s-%s\n", VERSION, PATCHLEVEL);
+			printf("syslogd %s.%s\n", VERSION, PATCHLEVEL);
 			exit (0);
 		case '?':
 		default:
@@ -1200,6 +1205,7 @@ static int create_unix_socket(const char *path)
 #ifndef SYSV
 		die(0);
 #endif
+		return -1;
 	}
 	return fd;
 }
@@ -2403,20 +2409,20 @@ void init()
 
 	if ( AcceptRemote )
 #ifdef DEBRELEASE
-		logmsg(LOG_SYSLOG|LOG_INFO, "syslogd " VERSION "-" PATCHLEVEL "#" DEBRELEASE \
+		logmsg(LOG_SYSLOG|LOG_INFO, "syslogd " VERSION "." PATCHLEVEL "#" DEBRELEASE \
 		       ": restart (remote reception)." , LocalHostName, \
 		       	ADDDATE);
 #else
-		logmsg(LOG_SYSLOG|LOG_INFO, "syslogd " VERSION "-" PATCHLEVEL \
+		logmsg(LOG_SYSLOG|LOG_INFO, "syslogd " VERSION "." PATCHLEVEL \
 		       ": restart (remote reception)." , LocalHostName, \
 		       	ADDDATE);
 #endif
 	else
 #ifdef DEBRELEASE
-		logmsg(LOG_SYSLOG|LOG_INFO, "syslogd " VERSION "-" PATCHLEVEL "#" DEBRELEASE \
+		logmsg(LOG_SYSLOG|LOG_INFO, "syslogd " VERSION "." PATCHLEVEL "#" DEBRELEASE \
 		       ": restart." , LocalHostName, ADDDATE);
 #else
-		logmsg(LOG_SYSLOG|LOG_INFO, "syslogd " VERSION "-" PATCHLEVEL \
+		logmsg(LOG_SYSLOG|LOG_INFO, "syslogd " VERSION "." PATCHLEVEL \
 		       ": restart." , LocalHostName, ADDDATE);
 #endif
 	(void) signal(SIGHUP, sighup_handler);
